==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Cliquer sur l&apos;icône de la barre d&apos;état 
ou appuyez à nouveau sur le raccourci pour arrêter l&apos;enregistrement</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>L&apos;enregistrement a échoué. Veuillez l&apos;enregistrer dans votre répertoire personnel.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Capture d&apos;écran terminée</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zone de sélection</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La capture d&apos;écran démarrera dans %1 secondes</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Sauvegarde du fichier d&apos;enregistrement d&apos;écran, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enregistrement terminé</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La capture d&apos;écran démarrera dans %1 secondes</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Saisissez du texte ici</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Démarrer/Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Quitter/Enregistrer</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Dessin</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajustement de la taille</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Démarrage rapide</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capture d&apos;écran de la fenêtre</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Délai de la capture d&apos;écran</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Capture d&apos;écran complète</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copier dans le presse-papiers</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenter la hauteur</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenter la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenter la largeur à gauche</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenter la largeur à droite</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuer la hauteur</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuer la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuer la largeur à gauche</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuer la largeur à droite</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Flou</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaïque</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Son activé</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Système audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Son désactivé</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Afficher la séquence de touches</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Masquer la frappe</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Caméra activée</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Caméra désactivée</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Afficher le clic</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>Masquer le clic</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS :</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enregistrer dans</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>Éditer </translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Afficher le pointeur</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Enregistrements</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>L&apos;enregistrement de l&apos;écran n&apos;est pas pris en charge actuellement</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Cliquer sur l&apos;icône de la barre d&apos;état 
ou appuyez à nouveau sur le raccourci pour arrêter l&apos;enregistrement</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>L&apos;enregistrement a échoué. Veuillez l&apos;enregistrer dans votre répertoire personnel.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Capture d&apos;écran terminée</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zone de sélection</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Sauvegarde du fichier d&apos;enregistrement d&apos;écran, veuillez patienter...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Comme l&apos;effet de fenêtre est désactivé pendant le processus, l&apos;enregistrement doit être arrêté</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enregistrement terminé</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enregistré dans %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La capture d&apos;écran démarrera dans %1 secondes</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Saisissez du texte ici</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Démarrer/Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Quitter/Enregistrer</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Dessin</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajustement de la taille</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Démarrage rapide</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capture d&apos;écran de la fenêtre</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Délai de la capture d&apos;écran</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Capture d&apos;écran complète</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenter la hauteur</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenter la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenter la largeur à gauche</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenter la largeur à droite</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Diminuer la hauteur</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Diminuer la hauteur vers le bas</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Diminuer la largeur à gauche</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Diminuer la largeur à droite</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Frappe</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Démarrer l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Commencer l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Souris</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Flou</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaïque</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Son activé</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Système audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Son désactivé</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Afficher la séquence de touches</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Masquer la frappe</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Caméra activée</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Caméra désactivée</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Afficher le clic</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS :</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enregistrer dans</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Afficher le pointeur</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Souris</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Afficher le pointeur</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajuster la zone d&apos;enregistrement dans %1 *%2 pour obtenir un meilleur effet vidéo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Enregistrements</translation>
    </message>
</context>
</TS>
